@@ -14,7 +14,7 @@ package Debug::Fork::Tmux::Config;
 use strict;
 use warnings;
 
-our $VERSION = '1.000004';    # VERSION
+our $VERSION = '1.000007';    # VERSION
 #
 ### MODULES ###
 #
@@ -115,7 +115,7 @@ Debug::Fork::Tmux::Config - Configuration system for Debug::Fork::Tmux
 
 =head1 VERSION
 
-This documentation refers to the module contained in the distribution C<Debug-Fork-Tmux> version 1.000004.
+This documentation refers to the module contained in the distribution C<Debug-Fork-Tmux> version 1.000007.
 
 =head1 SYNOPSIS
 
@@ -179,6 +179,95 @@ You can find documentation for this module with the perldoc command.
 
   perldoc Debug::Fork::Tmux
 
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
+=over 4
+
+=item *
+
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<http://metacpan.org/release/Debug-Fork-Tmux>
+
+=item *
+
+Search CPAN
+
+The default CPAN search engine, useful to view POD in HTML format.
+
+L<http://search.cpan.org/dist/Debug-Fork-Tmux>
+
+=item *
+
+RT: CPAN's Bug Tracker
+
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Debug-Fork-Tmux>
+
+=item *
+
+AnnoCPAN
+
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
+
+L<http://annocpan.org/dist/Debug-Fork-Tmux>
+
+=item *
+
+CPAN Ratings
+
+The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
+
+L<http://cpanratings.perl.org/d/Debug-Fork-Tmux>
+
+=item *
+
+CPAN Forum
+
+The CPAN Forum is a web forum for discussing Perl modules.
+
+L<http://cpanforum.com/dist/Debug-Fork-Tmux>
+
+=item *
+
+CPANTS
+
+The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
+
+L<http://cpants.perl.org/dist/overview/Debug-Fork-Tmux>
+
+=item *
+
+CPAN Testers
+
+The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+
+L<http://www.cpantesters.org/distro/D/Debug-Fork-Tmux>
+
+=item *
+
+CPAN Testers Matrix
+
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+
+L<http://matrix.cpantesters.org/?dist=Debug-Fork-Tmux>
+
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=Debug::Fork::Tmux>
+
+=back
+
 =head2 Email
 
 You can email the author of this module at C<peter@vereshagin.org> asking for help with any problems you have.
